@@ -1,14 +1,14 @@
 <?php
 /**
- * $Horde: kronolith/contacts.php,v 1.16.10.5 2007/01/02 13:55:04 jan Exp $
+ * $Horde: kronolith/contacts.php,v 1.16.10.7 2008/01/02 11:32:16 jan Exp $
  *
- * Copyright 2002-2007 Marcus I. Ryan <marcus@riboflavin.net>
+ * Copyright 2002-2008 The Horde Project (http://www.horde.org/)
  *
- * See the enclosed file COPYING for license information (GPL). If you did not
- * receive this file, see http://www.fsf.org/copyleft/gpl.html.
+ * See the enclosed file COPYING for license information (GPL). If you
+ * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
  */
 
-define('KRONOLITH_BASE', dirname(__FILE__));
+@define('KRONOLITH_BASE', dirname(__FILE__));
 require_once KRONOLITH_BASE . '/lib/base.php';
 
 if (!Auth::getAuth()) {
