@@ -1,11 +1,13 @@
 <?php
 /**
- * $Horde: kronolith/data.php,v 1.72.2.12 2006/10/18 04:22:26 chuck Exp $
+ * $Horde: kronolith/data.php,v 1.72.2.16 2008/01/10 16:16:49 jan Exp $
  *
- * Copyright 2001-2006 Jan Schneider <jan@horde.org>
+ * Copyright 2001-2008 The Horde Project (http://www.horde.org/)
  *
- * See the enclosed file COPYING for license information (GPL).  If you
+ * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
+ *
+ * @author Jan Schneider <jan@horde.org>
  */
 
 function _cleanup()
@@ -97,80 +99,92 @@ case 'export':
         $calendars = array($calendars);
     }
     foreach ($calendars as $cal) {
-        if ($kronolith->getCalendar() != $cal) {
-            $kronolith->close();
-            $kronolith->open($cal);
+        if ($kronolith_driver->getCalendar() != $cal) {
+            $kronolith_driver->open($cal);
         }
-        $events[$cal] = $kronolith->listEvents($start, $end);
+        $events[$cal] = $kronolith_driver->listEvents($start, $end);
     }
 
-    if (!count($events)) {
+    if (!$events) {
         $notification->push(_("There were no events to export."), 'horde.message');
         $error = true;
         break;
-    } else {
-        $exportID = Util::getFormData('exportID');
-        switch ($exportID) {
-        case EXPORT_CSV:
-            $data = array();
-            foreach ($events as $cal => $calevents) {
-                if ($kronolith->getCalendar() != $cal) {
-                    $kronolith->close();
-                    $kronolith->open($cal);
-                }
-                foreach ($calevents as $eventId) {
-                    $event = &$kronolith->getEvent($eventId);
+    }
 
-                    $row = array();
-                    $row['title'] = $event->getTitle();
-                    $row['category'] = $event->category;
-                    $row['location'] = $event->location;
-                    $row['description'] = $event->description;
-                    $row['keywords'] = implode(',', $event->keywords);
-                    $row['start_date'] = sprintf('%d-%02d-%02d', $event->start->year, $event->start->month, $event->start->mday);
-                    $row['start_time'] = sprintf('%02d:%02d:%02d', $event->start->hour, $event->start->min, $event->start->sec);
-                    $row['end_date'] = sprintf('%d-%02d-%02d', $event->end->year, $event->end->month, $event->end->mday);
-                    $row['end_time'] = sprintf('%02d:%02d:%02d', $event->end->hour, $event->end->min, $event->end->sec);
-                    $row['alarm'] = $event->alarm;
-                    $row['recur_type'] = $event->recurType;
-                    if ($event->recurType != KRONOLITH_RECUR_NONE) {
-                        $row['recur_end_date'] = sprintf('%d-%02d-%02d', $event->recurEnd->year, $event->recurEnd->month, $event->recurEnd->mday);
-                        $row['recur_interval'] = $event->recurInterval;
-                        $row['recur_data'] = $event->recurData;
-                    } else {
-                        $row['recur_end_date'] = null;
-                        $row['recur_interval'] = null;
-                        $row['recur_data'] = null;
-                    }
-                    $data[] = $row;
-                }
+    $exportID = Util::getFormData('exportID');
+    switch ($exportID) {
+    case EXPORT_CSV:
+        $data = array();
+        foreach ($events as $cal => $calevents) {
+            if ($kronolith_driver->getCalendar() != $cal) {
+                $kronolith_driver->open($cal);
             }
-
-            $csv = &Horde_Data::singleton('csv');
-            $csv->exportFile(_("events.csv"), $data, true);
-            exit;
-
-        case EXPORT_ICALENDAR:
-            require_once 'Horde/Identity.php';
-            require_once 'Horde/iCalendar.php';
-            $iCal = &new Horde_iCalendar();
-
-            foreach ($events as $cal => $calevents) {
-                if ($kronolith->getCalendar() != $cal) {
-                    $kronolith->close();
-                    $kronolith->open($cal);
+            foreach ($calevents as $eventId) {
+                $event = &$kronolith_driver->getEvent($eventId);
+                if (is_a($event, 'PEAR_Error')) {
+                    continue;
                 }
 
-                foreach ($calevents as $id) {
-                    $event = &$kronolith->getEvent($id);
-                    $iCal->addComponent($event->toiCalendar($iCal));
+                $row = array();
+                $row['title'] = $event->getTitle();
+                $row['category'] = $event->category;
+                $row['location'] = $event->location;
+                $row['description'] = $event->description;
+                $row['keywords'] = implode(',', $event->keywords);
+                $row['start_date'] = sprintf('%d-%02d-%02d', $event->start->year, $event->start->month, $event->start->mday);
+                $row['start_time'] = sprintf('%02d:%02d:%02d', $event->start->hour, $event->start->min, $event->start->sec);
+                $row['end_date'] = sprintf('%d-%02d-%02d', $event->end->year, $event->end->month, $event->end->mday);
+                $row['end_time'] = sprintf('%02d:%02d:%02d', $event->end->hour, $event->end->min, $event->end->sec);
+                $row['alarm'] = $event->alarm;
+                if ($event->recurs()) {
+                    $row['recur_type'] = $event->recurrence->getRecurType();
+                    $row['recur_end_date'] = sprintf('%d-%02d-%02d',
+                                                     $event->recurrence->recurEnd->year,
+                                                     $event->recurrence->recurEnd->month,
+                                                     $event->recurrence->recurEnd->mday);
+                    $row['recur_interval'] = $event->recurrence->getRecurInterval();
+                    $row['recur_data'] = $event->recurrence->recurData;
+                } else {
+                    $row['recur_type'] = null;
+                    $row['recur_end_date'] = null;
+                    $row['recur_interval'] = null;
+                    $row['recur_data'] = null;
                 }
+                $data[] = $row;
             }
-            $data = $iCal->exportvCalendar();
-            $browser->downloadHeaders(_("events.ics"), 'text/calendar', false, strlen($data));
-            echo $data;
-            exit;
         }
+
+        $csv = &Horde_Data::singleton('csv');
+        $csv->exportFile(_("events.csv"), $data, true);
+        exit;
+
+    case EXPORT_ICALENDAR:
+        require_once 'Horde/Identity.php';
+        require_once 'Horde/iCalendar.php';
+        $iCal = new Horde_iCalendar();
+
+        $calNames = array();
+        foreach ($events as $cal => $calevents) {
+            if ($kronolith_driver->getCalendar() != $cal) {
+                $kronolith_driver->open($cal);
+            }
+
+            $share = &$kronolith_shares->getShare($cal);
+            $calNames[] = $share->get('name');
+            foreach ($calevents as $id) {
+                $event = &$kronolith_driver->getEvent($id);
+                if (is_a($event, 'PEAR_Error')) {
+                    continue;
+                }
+                $iCal->addComponent($event->toiCalendar($iCal));
+            }
+        }
+
+        $iCal->setAttribute('X-WR-CALNAME', String::convertCharset(implode(', ', $calNames), NLS::getCharset(), 'utf-8'));
+        $data = $iCal->exportvCalendar();
+        $browser->downloadHeaders(_("events.ics"), 'text/calendar', false, strlen($data));
+        echo $data;
+        exit;
     }
     break;
 
@@ -224,7 +238,7 @@ if (is_array($next_step)) {
     if ($max_events !== true) {
         $num_events = Kronolith::countEvents();
     }
-    $kronolith->open($_SESSION['import_data']['import_cal']);
+    $kronolith_driver->open($_SESSION['import_data']['import_cal']);
 
     if (!count($next_step)) {
         $notification->push(sprintf(_("The %s file didn't contain any events."),
@@ -233,7 +247,7 @@ if (is_array($next_step)) {
     } else {
         /* Purge old calendar if requested. */
         if ($_SESSION['import_data']['purge']) {
-            $result = $kronolith->delete($_SESSION['import_data']['import_cal']);
+            $result = $kronolith_driver->delete($_SESSION['import_data']['import_cal']);
             if (is_a($result, 'PEAR_Error')) {
                 $notification->push(sprintf(_("The calendar could not be purged: %s"), $result->getMessage()), 'horde.error');
             } else {
@@ -251,7 +265,7 @@ if (is_array($next_step)) {
             $notification->push($message, 'horde.error', array('content.raw'));
             break;
         }
-        $event = &$kronolith->getEvent();
+        $event = &$kronolith_driver->getEvent();
         if (!$event || is_a($event, 'PEAR_Error')) {
             $msg = _("Can't create a new event.");
             if (is_a($event, 'PEAR_Error')) {
