@@ -1,18 +1,25 @@
 <?php
 /**
- * $Horde: kronolith/fb.php,v 1.25.10.6 2007/02/15 19:11:43 jan Exp $
+ * $Horde: kronolith/fb.php,v 1.25.10.10 2008/01/02 11:32:16 jan Exp $
  *
- * Copyright 1999-2007 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2008 The Horde Project (http://www.horde.org/)
  *
- * See the enclosed file COPYING for license information (GPL).  If you
+ * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
+ *
+ * @author Chuck Hagenbuch <chuck@horde.org>
  */
 
 @define('AUTH_HANDLER', true);
 @define('KRONOLITH_BASE', dirname(__FILE__));
+$session_control = 'none';
 require_once KRONOLITH_BASE . '/lib/base.php';
+require_once KRONOLITH_BASE . '/lib/FreeBusy.php';
 require_once 'Horde/Cache.php';
 
+// We want to always generate UTF-8 iCalendar data.
+NLS::setCharset('UTF-8');
+
 // Determine the username to show free/busy time for.
 $cal = Util::getFormData('c');
 $user = Util::getFormData('u');
@@ -24,13 +31,14 @@ if (!empty($cal)) {
     $user = basename($_SERVER['PATH_INFO']);
 }
 
-$cache = &Horde_Cache::singleton($conf['cache']['driver'], Horde::getDriverConfig('cache', $conf['cache']['driver']));
+$cache = Horde_Cache::factory($conf['cache']['driver'], Horde::getDriverConfig('cache', $conf['cache']['driver']));
 $key = 'kronolith.fb.' . ($user ? 'u.' . $user : 'c.' . $cal);
 $fb = $cache->get($key, 360);
 if (!$fb) {
     if ($user) {
         $prefs = &Prefs::singleton($conf['prefs']['driver'], 'kronolith', $user, '', null, false);
         $prefs->retrieve();
+        NLS::setTimeZone();
         $cal = @unserialize($prefs->getValue('fb_cals'));
         if (is_array($cal)) {
             $cal = implode('|', $cal);
@@ -47,7 +55,7 @@ if (!$fb) {
         }
     }
 
-    $fb = Kronolith::generateFreeBusy(explode('|', $cal), null, null, false, $user);
+    $fb = Kronolith_FreeBusy::generate(explode('|', $cal), null, null, false, $user);
     if (is_a($fb, 'PEAR_Error')) {
         Horde::logMessage($fb, __FILE__, __LINE__, PEAR_LOG_ERR);
         exit;
@@ -55,5 +63,8 @@ if (!$fb) {
     $cache->set($key, $fb);
 }
 
-$browser->downloadHeaders(($user ? $user : $cal) . '.vfb', 'text/calendar', true, strlen($fb));
+$browser->downloadHeaders(($user ? $user : $cal) . '.vfb',
+                          'text/calendar; charset=' . NLS::getCharset(),
+                          true,
+                          strlen($fb));
 echo $fb;
