@@ -1,11 +1,13 @@
 <?php
 /**
- * $Horde: kronolith/ics.php,v 1.5.2.5 2007/03/13 00:22:31 jan Exp $
+ * $Horde: kronolith/ics.php,v 1.5.2.10 2008/01/10 16:16:49 jan Exp $
  *
- * Copyright 1999-2007 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2008 The Horde Project (http://www.horde.org/)
  *
- * See the enclosed file COPYING for license information (GPL).  If you
+ * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
+ *
+ * @author Chuck Hagenbuch <chuck@horde.org>
  */
 
 @define('AUTH_HANDLER', true);
@@ -15,6 +17,9 @@ require_once KRONOLITH_BASE . '/lib/base.php';
 require_once 'Horde/Cache.php';
 require_once 'Horde/iCalendar.php';
 
+// We want to always generate UTF-8 iCalendar data.
+NLS::setCharset('UTF-8');
+
 // Determine which calendar to export.
 $calendar = Util::getFormData('c');
 if (empty($calendar) && !empty($_SERVER['PATH_INFO'])) {
@@ -43,19 +48,28 @@ if (!$share->hasPermission('', PERMS_READ)) {
     }
 }
 
+// If we've authenticated, we need to re-load global share variables
+// now.
+if (Auth::getAuth()) {
+    Kronolith::initialize();
+}
+
 $cache = &Horde_Cache::singleton($conf['cache']['driver'], Horde::getDriverConfig('cache', $conf['cache']['driver']));
 $key = 'kronolith.ics.' . $calendar;
 
 $ics = $cache->get($key, 360);
 if (!$ics) {
-    $kronolith->open($calendar);
-    $events = $kronolith->listEvents(null, null);
+    $kronolith_driver->open($calendar);
+    $events = $kronolith_driver->listEvents();
 
-    $iCal = &new Horde_iCalendar();
-    $iCal->setAttribute('X-WR-CALNAME', $share->get('name'));
+    $iCal = new Horde_iCalendar();
+    $iCal->setAttribute('X-WR-CALNAME', String::convertCharset($share->get('name'), NLS::getCharset(), 'utf-8'));
 
     foreach ($events as $id) {
-        $event = &$kronolith->getEvent($id);
+        $event = &$kronolith_driver->getEvent($id);
+        if (is_a($event, 'PEAR_Error')) {
+            continue;
+        }
         $iCal->addComponent($event->toiCalendar($iCal));
     }
 
@@ -63,5 +77,8 @@ if (!$ics) {
     $cache->set($key, $ics);
 }
 
-$browser->downloadHeaders($calendar . '.ics', 'text/calendar', true, strlen($ics));
+$browser->downloadHeaders($calendar . '.ics',
+                          'text/calendar; charset=' . NLS::getCharset(),
+                          true,
+                          strlen($ics));
 echo $ics;
