@@ -5,12 +5,11 @@ require_once 'Horde/Template.php';
 /**
  * This class represent a view of multiple free busy information sets.
  *
- * Copyright 2003-2007 Mike Cochrane <mike@graftonhall.co.nz>
- * Copyright 2004-2007 Jan Schneider <jan@horde.org>
+ * Copyright 2003-2008 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information.
  *
- * $Horde: kronolith/lib/FBView.php,v 1.10.10.11 2007/01/02 13:55:05 jan Exp $
+ * $Horde: kronolith/lib/FBView.php,v 1.10.10.14 2008/03/15 17:30:59 jan Exp $
  *
  * @author  Mike Cochrane <mike@graftonhall.co.nz>
  * @author  Jan Schneider <jan@horde.org>
@@ -47,7 +46,7 @@ class Kronolith_FreeBusy_View {
         $this->_render($day);
 
         require_once 'Horde/iCalendar.php';
-        $vCal = &new Horde_iCalendar();
+        $vCal = new Horde_iCalendar();
         $required = &Horde_iCalendar::newComponent('vfreebusy', $vCal);
         foreach ($this->_requiredMembers as $member) {
             $required->merge($member, false);
@@ -72,7 +71,7 @@ class Kronolith_FreeBusy_View {
         $template = &new Horde_Template();
         $template->set('title', $this->_title());
 
-        $html = $template->fetch(KRONOLITH_TEMPLATES . '/fbview/header.tpl') .
+        $html = $template->fetch(KRONOLITH_TEMPLATES . '/fbview/header.html') .
             '<div class="fbgrid">';
 
         $hours_html = $this->_hours();
@@ -84,84 +83,86 @@ class Kronolith_FreeBusy_View {
 
         // Required to attend.
         if (count($this->_requiredMembers) > 0) {
-            $template = &new Horde_Template();
+            $template = new Horde_Template();
             $rows = '';
             foreach ($this->_requiredMembers as $member) {
-                $blocks = $this->_getBlocks($member, $member->getBusyPeriods(), 'busyblock.tpl', _("Busy"));
-                $template = &new Horde_Template();
+                $member->simplify();
+                $blocks = $this->_getBlocks($member, $member->getBusyPeriods(), 'busyblock.html', _("Busy"));
+                $template = new Horde_Template();
                 $template->set('blocks', $blocks);
                 $template->set('name', $member->getName());
-                $rows .= $template->fetch(KRONOLITH_TEMPLATES . '/fbview/row.tpl');
+                $rows .= $template->fetch(KRONOLITH_TEMPLATES . '/fbview/row.html');
             }
 
-            $template = &new Horde_Template();
+            $template = new Horde_Template();
             $template->set('title', _("Required Attendees"));
             $template->set('rows', $rows);
             $template->set('span', count($this->_timeBlocks));
             $template->set('hours', $hours_html);
             $template->set('legend', '');
-            $html .= $template->fetch(KRONOLITH_TEMPLATES . '/fbview/section.tpl');
+            $html .= $template->fetch(KRONOLITH_TEMPLATES . '/fbview/section.html');
         }
 
         // Optional to attend.
         if (count($this->_optionalMembers) > 0) {
-            $template = &new Horde_Template();
+            $template = new Horde_Template();
             $rows = '';
             foreach ($this->_optionalMembers as $member) {
-                $blocks = $this->_getBlocks($member, $member->getBusyPeriods(), 'busyblock.tpl', _("Busy"));
-                $template = &new Horde_Template();
+                $member->simplify();
+                $blocks = $this->_getBlocks($member, $member->getBusyPeriods(), 'busyblock.html', _("Busy"));
+                $template = new Horde_Template();
                 $template->set('blocks', $blocks);
                 $template->set('name', $member->getName());
-                $rows .= $template->fetch(KRONOLITH_TEMPLATES . '/fbview/row.tpl');
+                $rows .= $template->fetch(KRONOLITH_TEMPLATES . '/fbview/row.html');
             }
 
-            $template = &new Horde_Template();
+            $template = new Horde_Template();
             $template->set('title', _("Optional Attendees"));
             $template->set('rows', $rows);
             $template->set('span', count($this->_timeBlocks));
             $template->set('hours', $hours_html);
             $template->set('legend', '');
-            $html .= $template->fetch(KRONOLITH_TEMPLATES . '/fbview/section.tpl');
+            $html .= $template->fetch(KRONOLITH_TEMPLATES . '/fbview/section.html');
         }
 
         // Possible meeting times.
         $optimal->setAttribute('ORGANIZER', _("All Attendees"));
         $blocks = $this->_getBlocks($optimal,
                                     $optimal->getFreePeriods($this->_startStamp, $this->_endStamp),
-                                    'meetingblock.tpl', _("All Attendees"));
+                                    'meetingblock.html', _("All Attendees"));
 
-        $template = &new Horde_Template();
+        $template = new Horde_Template();
         $template->set('name', _("All Attendees"));
         $template->set('blocks', $blocks);
-        $rows = $template->fetch(KRONOLITH_TEMPLATES . '/fbview/row.tpl');
+        $rows = $template->fetch(KRONOLITH_TEMPLATES . '/fbview/row.html');
 
         // Possible meeting times.
         $required->setAttribute('ORGANIZER', _("Required Attendees"));
         $blocks = $this->_getBlocks($required,
                                     $required->getFreePeriods($this->_startStamp, $this->_endStamp),
-                                    'meetingblock.tpl', _("Required Attendees"));
+                                    'meetingblock.html', _("Required Attendees"));
 
-        $template = &new Horde_Template();
+        $template = new Horde_Template();
         $template->set('name', _("Required Attendees"));
         $template->set('blocks', $blocks);
-        $rows .= $template->fetch(KRONOLITH_TEMPLATES . '/fbview/row.tpl');
+        $rows .= $template->fetch(KRONOLITH_TEMPLATES . '/fbview/row.html');
 
         // Reset locale.
         setlocale(LC_NUMERIC, $lc);
 
-        $template = &new Horde_Template();
+        $template = new Horde_Template();
         $template->set('rows', $rows);
         $template->set('title', _("Overview"));
         $template->set('span', count($this->_timeBlocks));
         $template->set('hours', $hours_html);
         if ($prefs->getValue('show_fb_legend')) {
             $template->setOption('gettext', true);
-            $template->set('legend', $template->fetch(KRONOLITH_TEMPLATES . '/fbview/legend.tpl'));
+            $template->set('legend', $template->fetch(KRONOLITH_TEMPLATES . '/fbview/legend.html'));
         } else {
             $template->set('legend', '');
         }
 
-        return $html . $template->fetch(KRONOLITH_TEMPLATES . '/fbview/section.tpl') . '</div>';
+        return $html . $template->fetch(KRONOLITH_TEMPLATES . '/fbview/section.html') . '</div>';
     }
 
     /**
@@ -220,7 +221,7 @@ class Kronolith_FreeBusy_View {
 
     function _getBlocks($member, $periods, $blockfile, $label)
     {
-        $template = &new Horde_Template();
+        $template = new Horde_Template();
         $template->set('label', $label);
 
         reset($periods);
@@ -230,7 +231,7 @@ class Kronolith_FreeBusy_View {
         foreach ($this->_timeBlocks as $start => $end) {
             if ($member->getStart() > $start ||
                 $member->getEnd() < $end) {
-                $blocks .= $template->fetch(KRONOLITH_TEMPLATES . '/fbview/unknownblock.tpl');
+                $blocks .= $template->fetch(KRONOLITH_TEMPLATES . '/fbview/unknownblock.html');
                 continue;
             }
 
@@ -248,13 +249,13 @@ class Kronolith_FreeBusy_View {
 
                 $left = ($l_start - $start) / $plen;
                 $width = ($l_end - $l_start) / $plen;
- 
+
                 $template->set('left', $left . '%');
                 $template->set('width', $width . '%');
 
                 $blocks .= $template->fetch(KRONOLITH_TEMPLATES . '/fbview/' . $blockfile);
             } else {
-                $blocks .= $template->fetch(KRONOLITH_TEMPLATES . '/fbview/emptyblock.tpl');
+                $blocks .= $template->fetch(KRONOLITH_TEMPLATES . '/fbview/emptyblock.html');
             }
         }
 
