@@ -1,4 +1,4 @@
--- $Horde: kronolith/scripts/upgrades/1.1_to_2.0.mysql.sql,v 1.4 2004/12/21 15:52:32 chuck Exp $
+-- $Horde: kronolith/scripts/upgrades/1.1_to_2.0.mysql.sql,v 1.4.2.1 2007/12/20 14:12:58 jan Exp $
 --
 -- You can simply execute this file in your database.
 --
@@ -19,11 +19,9 @@ CREATE INDEX kronolith_uid_idx ON kronolith_events (event_uid);
 
 CREATE TABLE kronolith_storage (
     vfb_owner      VARCHAR(255) DEFAULT NULL,
-    vfb_email      VARCHAR(255) NOT NULL DEFAULT '',
+    vfb_email      VARCHAR(255) DEFAULT '' NOT NULL,
     vfb_serialized TEXT NOT NULL
 );
 
 CREATE INDEX kronolith_vfb_owner_idx ON kronolith_storage (vfb_owner);
 CREATE INDEX kronolith_vfb_email_idx ON kronolith_storage (vfb_email);
-
-GRANT SELECT, INSERT, UPDATE, DELETE ON kronolith_storage TO horde@localhost;
