@@ -1,11 +1,13 @@
 <?php
 /**
- * $Horde: kronolith/themes/categoryCSS.php,v 1.4.2.2 2006/01/01 21:29:04 jan Exp $
+ * $Horde: kronolith/themes/categoryCSS.php,v 1.4.2.6 2008/05/25 16:46:04 jan Exp $
  *
- * Copyright 1999-2006 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2008 The Horde Project (http://www.horde.org/)
  *
- * See the enclosed file COPYING for license information (GPL).  If you
+ * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
+ *
+ * @author Chuck Hagenbuch <chuck@horde.org>
  */
 
 @define('AUTH_HANDLER', true);
@@ -26,10 +28,9 @@ foreach ($colors as $category => $color) {
             '.month-eventBox a:hover, .week-eventBox a:hover, .day-eventBox a:hover, .block-eventBox a:hover, .legend-eventBox a:hover { ';
     } else {
         $class = '.category' . md5($category);
-        echo "$class, $class a, $class a:hover { ";
+        echo "$class, .linedRow td$class, $class a, $class a:hover { ";
     }
 
-    echo 'border-color: ' . Horde_Image::modifyColor($color, -0x44) . '; ',
-        'color: ' . (isset($fgColors[$category]) ? $fgColors[$category] : $fgColors['_default_']) . '; ',
+    echo 'color: ' . (isset($fgColors[$category]) ? $fgColors[$category] : $fgColors['_default_']) . '; ',
         'background: ' . $color . "; }\n";
 }
